Learn R Programming

AHPWR (version 0.1.2)

calcula_prioridades: Calculates the priority vector of a paired matrix

Description

Calculates the priority vector of a paired array based on a list

Usage

calcula_prioridades(lista)

Value

Returns a list containing priority vectors for each matrix in the read list

Arguments

lista

a paired matrix list

Author

Lyncoln Oliveira