Learn R Programming

AHPWR (version 0.1.2)

ler: Read an excel file containing the paired matrices

Description

Function to read an excel file containing the paired matrices and turn all spreadsheets into a list of matrices in R.

Usage

ler(caminho)

Value

Returns a list containing the matrices from the excel file.

Arguments

caminho

Address to an excel file that contains the worksheets.

Author

Lyncoln Oliveira

Examples

Run this code
# Criando um arquivo de exemplo para o teste
library(openxlsx)
tmp <- tempfile(fileext = ".xlsx")
m <- matrix(c(1, 2, 0.5, 1), nrow = 2)
openxlsx::write.xlsx(list(Sheet1 = m), file = tmp)

# Testando a função
lista = ler(tmp)
lista

Run the code above in your browser using DataLab