Learn R Programming

AHPWR (version 0.1.2)

matrix_ahp: creates a dataframe containing the judments holistic

Description

Function to build the judment matrix

Function to build the judgment matrix based on a vector of weights.

Usage

matrix_ahp(x, y)

matrix_ahp(x, y)

Value

Returns a judment matrice.

Returns a square judgment matrix (n x n).

Arguments

x

A vector of names (criteria or choices).

y

A vector of weights on the Saaty scale, typically in [1, 9].

Author

Luciane Ferreira Alcoforado

Examples

Run this code
x=c("c1", "c2", "c3", "c4")
y=c(3, 9, 2, 8)
matrix_ahp(x,y)

x=c("a1", "a2", "a3", "a4", "a5")
y=c(1, 9, 1.5, 8, 6)
matrix_ahp(x,y)
x <- c("c1", "c2", "c3", "c4")
y <- c(3, 9, 2, 8)
matrix_ahp(x, y)

Run the code above in your browser using DataLab