Learn R Programming

AHPWR (version 0.1.2)

matriz_julgamento: Create paired matrix and can test saaty consistency rate

Description

Function that Create paired matrix and can test saaty consistency rate

Usage

matriz_julgamento(n_comp, CR = TRUE, n_matrix = 1)

Value

Returns a list with 2 positions. First position contains the paired matrices and the second position their consistency rates

Arguments

n_comp

Number of elements to be evaluated

CR

If TRUE also returns the consistency rate of saaty, if FALSE returns only matrix

n_matrix

Number of matrix to be created

Author

Lyncoln Oliveira