powered by
Function to build the judment matrix
Function to build the judgment matrix based on a vector of weights.
matrix_ahp(x, y)matrix_ahp(x, y)
matrix_ahp(x, y)
Returns a judment matrice.
Returns a square judgment matrix (n x n).
A vector of names (criteria or choices).
A vector of weights on the Saaty scale, typically in [1, 9].
Luciane Ferreira Alcoforado
x=c("c1", "c2", "c3", "c4") y=c(3, 9, 2, 8) matrix_ahp(x,y) x=c("a1", "a2", "a3", "a4", "a5") y=c(1, 9, 1.5, 8, 6) matrix_ahp(x,y) x <- c("c1", "c2", "c3", "c4") y <- c(3, 9, 2, 8) matrix_ahp(x, y)
Run the code above in your browser using DataLab