Function that Create paired matrix and can test saaty consistency rate
matriz_julgamento(n_comp, CR = TRUE, n_matrix = 1)Returns a list with 2 positions. First position contains the paired matrices and the second position their consistency rates
Number of elements to be evaluated
If TRUE also returns the consistency rate of saaty, if FALSE returns only matrix
Number of matrix to be created
Lyncoln Oliveira