powered by
Function to organizes a table with comparison matrix data
tabela_holistica(pesos)
Returns a table with assigned holistic weights, comparison matrix, priority vector and consistency ratio
vector with holistic weights for comparison or comparison matrix data
Luciane Ferreira Alcoforado & Orlando Longo
pesos = c(3, 7, 9, 2) names(pesos) = paste0("C",1:4) tabela_holistica(pesos) m = matrix_ahp(y=c(3,4,3,2.5), x=paste0("A",1:4)) tabela_holistica(pesos=m)
Run the code above in your browser using DataLab